Class: Emasser::Dashboards
- Inherits:
-
SubCommandBase
- Object
- Thor
- SubCommandBase
- Emasser::Dashboards
- Defined in:
- lib/emasser/get.rb
Overview
The Dashboards endpoints provide the ability to view data contained in dashboard exports. In the eMASS frontend, these dashboard exports are generated as Excel exports. Each dashboard dataset available from the API is automatically updated with the current configuration of the dashboard and the instance of eMASS as the dashboard changes.
Endpoints: (57)
System Status Dashboard
/api/dashboards/system-status-details
System Terms / Conditions Dashboards
/api/dashboards/system-terms-conditions-summary
/api/dashboards/system-terms-conditions-details
System Connectivity/CCSD
/api/dashboards/system-connectivity-ccsd-summary
/api/dashboards/system-connectivity-ccsd-details
System ATC/IATC
/api/dashboards/system-atc-iatc-details
System Questionnaire
/api/dashboards/system-questionnaire-summary
/api/dashboards/system-questionnaire-details
System Workflows Dashboard
/api/dashboards/system-workflows-history-summary
/api/dashboards/system-workflows-history-details
/api/dashboards/system-workflows-history-stage-details
System Security Controls Dashboard
/api/dashboards/system-control-compliance-summary
/api/dashboards/system-security-controls-details
/api/dashboards/system-assessment-procedures-details
System POA&M Dashboards
/api/dashboards/system-poam-summary
/api/dashboards/system-poam-details
System Artifacts Dashboards
/api/dashboards/system-artifacts-summary
/api/dashboards/system-artifacts-details
System Hardware Dashboards
/api/dashboards/system-hardware-summary
/api/dashboards/system-hardware-details
System Sensor Hardware Dashboards
/api/dashboards/system-sensor-hardware-summary
/api/dashboards/system-sensor-hardware-details
System Software Dashboards
/api/dashboards/system-software-summary
/api/dashboards/system-software-details
System Sensor Software Dashboards
/api/dashboards/system-sensor-software-summary
/api/dashboards/system-sensor-software-details
/api/dashboards/system-sensor-software-counts
System Critical Assets
/api/dashboards/system-critical-assets-summary
System Vulnerability Dashboards
/api/dashboards/system-vulnerability-summary
System Device Findings Dashboards
/api/dashboards/system-device-findings-summary
/api/dashboards/system-device-findings-details
System Applications Findings Dashboards
/api/dashboards/system-application-findings-summary
/api/dashboards/system-application-findings-details
Ports and Protocols Dashboards
/api/dashboards/system-ports-protocols-summary
/api/dashboards/system-ports-protocols-details
System CONMON Integration Status Dashboard
/api/dashboards/system-conmon-integration-status-summary
System Associations Dashboard
/api/dashboards/system-associations-details
User System Assignments Dashboard
/api/dashboards/user-system-assignments-details
Organization Migration Status
/api/dashboards/organization-migration-status-summary
System Migration Status
/api/dashboards/system-migration-status-summary
System FISMA Metrics
/api/dashboards/system-fisma-metrics
Coast Guard System FISMA Metrics
/api/dashboards/coastguard-system-fisma-metrics
System Privacy Dashboards
/api/dashboards/system-privacy-summary
VA OMB FISMA
/api/dashboards/va-omb-fisma-saop-summary
VA Systems Dashboard
/api/dashboards/va-system-icamp-tableau-poam-details
/api/dashboards/va-system-aa-summary
/api/dashboards/va-system-a2-summary
/api/dashboards/va-system-pl-109-reporting-summary
/api/dashboards/va-system-fisma-inventory-summary
/api/dashboards/va-system-fisma-inventory-crypto-summary
/api/dashboards/va-system-threat-risks-summary
/api/dashboards/va-system-threat-sources-details
/api/dashboards/va-system-threat-architecture-details
CMMC Assessment Dashboards
/api/dashboards/cmmc-assessment-status-summary
/api/dashboards/cmmc-assessment-requirements-compliance-summary
/api/dashboards/cmmc-assessment-security-requirements-details
/api/dashboards/cmmc-assessment-requirement-objectives-details
Class Method Summary collapse
Instance Method Summary collapse
- #application_findings_details ⇒ Object
- #application_findings_summary ⇒ Object
- #artifacts_details ⇒ Object
- #artifacts_summary ⇒ Object
- #assessment_procedures_details ⇒ Object
- #assignments_details ⇒ Object
- #associations_details ⇒ Object
- #atc_iatc_details ⇒ Object
- #cmmc_compliance_summary ⇒ Object
- #cmmc_requirement_objectives_details ⇒ Object
- #cmmc_security_requirements_details ⇒ Object
- #cmmc_status_summary ⇒ Object
- #coastguard_fisma_metrics ⇒ Object
- #connectivity_ccsd_details ⇒ Object
- #connectivity_ccsd_summary ⇒ Object
- #control_compliance_summary ⇒ Object
- #critical_assets_summary ⇒ Object
- #device_findings_details ⇒ Object
- #device_findings_summary ⇒ Object
- #fisma_inventory_crypto_summary ⇒ Object
- #fisma_inventory_summary ⇒ Object
- #fisma_metrics ⇒ Object
- #fisma_saop_summary ⇒ Object
- #hardware_details ⇒ Object
- #hardware_summary ⇒ Object
- #integration_status_summary ⇒ Object
- #organization_migration_status_summary ⇒ Object
- #poam_details ⇒ Object
- #poam_summary ⇒ Object
- #ports_protocols_details ⇒ Object
- #ports_protocols_summary ⇒ Object
- #privacy_summary ⇒ Object
- #questionnaire_details ⇒ Object
- #questionnaire_summary ⇒ Object
- #security_controls_details ⇒ Object
- #sensor_hardware_details ⇒ Object
- #sensor_hardware_summary ⇒ Object
- #sensor_software_counts ⇒ Object
- #sensor_software_details ⇒ Object
- #sensor_software_summary ⇒ Object
- #software_details ⇒ Object
- #software_summary ⇒ Object
- #status_details ⇒ Object
- #system_migration_status_summary ⇒ Object
- #terms_conditions_details ⇒ Object
- #terms_conditions_summary ⇒ Object
- #threat_architecture_details ⇒ Object
- #threat_risk_details ⇒ Object
- #threat_risk_summary ⇒ Object
- #va_a2_summary ⇒ Object
- #va_aa_summary ⇒ Object
- #va_icamp_tableau_poam_details ⇒ Object
- #va_pl_109_summary ⇒ Object
- #vulnerability_summary ⇒ Object
- #workflows_history_details ⇒ Object
- #workflows_history_stage_details ⇒ Object
- #workflows_history_summary ⇒ Object
Methods inherited from SubCommandBase
Methods included from OutputConverters
#change_to_datetime, #to_output_hash
Methods included from InputConverters
Methods included from OptionsParser
#optional_options, #required_options
Class Method Details
.exit_on_failure? ⇒ Boolean
854 855 856 |
# File 'lib/emasser/get.rb', line 854 def self.exit_on_failure? true end |
Instance Method Details
#application_findings_details ⇒ Object
1383 1384 1385 1386 1387 1388 1389 1390 1391 1392 1393 1394 |
# File 'lib/emasser/get.rb', line 1383 def application_findings_details = (@_initializer).keys = to_input_hash(, ) result = EmassClient::SystemApplicationFindingsDashboardsApi.new.get_system_application_findings_details( [:orgId], ) puts to_output_hash(result).green rescue EmassClient::ApiError => e puts 'Exception when calling SystemApplicationFindingsDashboardsApi->get_system_application_findings_details'.red puts to_output_hash(e) end |
#application_findings_summary ⇒ Object
1368 1369 1370 1371 1372 1373 1374 1375 1376 1377 1378 1379 |
# File 'lib/emasser/get.rb', line 1368 def application_findings_summary = (@_initializer).keys = to_input_hash(, ) result = EmassClient::SystemApplicationFindingsDashboardsApi.new.get_system_application_findings_summary( [:orgId], ) puts to_output_hash(result).green rescue EmassClient::ApiError => e puts 'Exception when calling SystemApplicationFindingsDashboardsApi->get_system_application_findings_summary'.red puts to_output_hash(e) end |
#artifacts_details ⇒ Object
1142 1143 1144 1145 1146 1147 1148 1149 1150 1151 1152 1153 |
# File 'lib/emasser/get.rb', line 1142 def artifacts_details = (@_initializer).keys = to_input_hash(, ) result = EmassClient::SystemArtifactsDashboardsApi.new.get_system_artifacts_details( [:orgId], ) puts to_output_hash(result).green rescue EmassClient::ApiError => e puts 'Exception when calling SystemArtifactsDashboardsApi->get_system_artifacts_details'.red puts to_output_hash(e) end |
#artifacts_summary ⇒ Object
1127 1128 1129 1130 1131 1132 1133 1134 1135 1136 1137 1138 |
# File 'lib/emasser/get.rb', line 1127 def artifacts_summary = (@_initializer).keys = to_input_hash(, ) result = EmassClient::SystemArtifactsDashboardsApi.new.get_system_artifacts_summary( [:orgId], ) puts to_output_hash(result).green rescue EmassClient::ApiError => e puts 'Exception when calling SystemArtifactsDashboardsApi->get_system_artifacts_summary'.red puts to_output_hash(e) end |
#assessment_procedures_details ⇒ Object
1078 1079 1080 1081 1082 1083 1084 1085 1086 1087 1088 1089 |
# File 'lib/emasser/get.rb', line 1078 def assessment_procedures_details = (@_initializer).keys = to_input_hash(, ) result = EmassClient::SystemSecurityControlsDashboardsApi.new.get_system_assessment_procedures_details( [:orgId], ) puts to_output_hash(result).green rescue EmassClient::ApiError => e puts 'Exception when calling SystemSecurityControlsDashboardsApi->get_system_assessment_procedures_details'.red puts to_output_hash(e) end |
#assignments_details ⇒ Object
1466 1467 1468 1469 1470 1471 1472 1473 1474 1475 1476 1477 |
# File 'lib/emasser/get.rb', line 1466 def assignments_details = (@_initializer).keys = to_input_hash(, ) result = EmassClient::UserSystemAssignmentsDashboardApi.new.get_user_system_assignments_details( [:orgId], ) puts to_output_hash(result).green rescue EmassClient::ApiError => e puts 'Exception when calling UserSystemAssignmentsDashboardApi->get_user_system_assignments_details'.red puts to_output_hash(e) end |
#associations_details ⇒ Object
1449 1450 1451 1452 1453 1454 1455 1456 1457 1458 1459 1460 |
# File 'lib/emasser/get.rb', line 1449 def associations_details = (@_initializer).keys = to_input_hash(, ) result = EmassClient::SystemAssociationsDashboardApi.new.get_system_associations_details( [:orgId], ) puts to_output_hash(result).green rescue EmassClient::ApiError => e puts 'Exception when calling SystemAssociationsDashboardApi->get_system_associations_details'.red puts to_output_hash(e) end |
#atc_iatc_details ⇒ Object
952 953 954 955 956 957 958 959 960 961 962 963 |
# File 'lib/emasser/get.rb', line 952 def atc_iatc_details = (@_initializer).keys = to_input_hash(, ) result = EmassClient::SystemATCIATCDashboardApi.new.get_system_atc_iatc_details( [:orgId], ) puts to_output_hash(result).green rescue EmassClient::ApiError => e puts 'Exception when calling SystemATCIATCDashboardApi->get_system_atc_iatc_details'.red puts to_output_hash(e) end |
#cmmc_compliance_summary ⇒ Object
1737 1738 1739 1740 1741 1742 1743 1744 1745 1746 1747 1748 |
# File 'lib/emasser/get.rb', line 1737 def cmmc_compliance_summary = (@_initializer).keys = to_input_hash(, ) result = EmassClient::CMMCAssessmentDashboardsApi.new.get_cmmc_assessment_requirements_compliance_summary( [:orgId], ) puts to_output_hash(result).green rescue EmassClient::ApiError => e puts 'Exception when calling CMMCAssessmentDashboardsApi->get_cmmc_assessment_requirements_compliance_summary'.red puts to_output_hash(e).yellow end |
#cmmc_requirement_objectives_details ⇒ Object
1767 1768 1769 1770 1771 1772 1773 1774 1775 1776 1777 1778 |
# File 'lib/emasser/get.rb', line 1767 def cmmc_requirement_objectives_details = (@_initializer).keys = to_input_hash(, ) result = EmassClient::CMMCAssessmentDashboardsApi.new.get_cmmc_assessment_requirement_objectives_details( [:orgId], ) puts to_output_hash(result).green rescue EmassClient::ApiError => e puts 'Exception when calling CMMCAssessmentDashboardsApi->get_cmmc_assessment_requirement_objectives_details'.red puts to_output_hash(e).yellow end |
#cmmc_security_requirements_details ⇒ Object
1752 1753 1754 1755 1756 1757 1758 1759 1760 1761 1762 1763 |
# File 'lib/emasser/get.rb', line 1752 def cmmc_security_requirements_details = (@_initializer).keys = to_input_hash(, ) result = EmassClient::CMMCAssessmentDashboardsApi.new.get_cmmc_assessment_security_requirements_details( [:orgId], ) puts to_output_hash(result).green rescue EmassClient::ApiError => e puts 'Exception when calling CMMCAssessmentDashboardsApi->get_cmmc_assessment_security_requirements_details'.red puts to_output_hash(e).yellow end |
#cmmc_status_summary ⇒ Object
1722 1723 1724 1725 1726 1727 1728 1729 1730 1731 1732 1733 |
# File 'lib/emasser/get.rb', line 1722 def cmmc_status_summary = (@_initializer).keys = to_input_hash(, ) result = EmassClient::CMMCAssessmentDashboardsApi.new.get_cmmc_assessment_status_summary( [:orgId], ) puts to_output_hash(result).green rescue EmassClient::ApiError => e puts 'Exception when calling CMMCAssessmentDashboardsApi->get_cmmc_assessment_status_summary'.red puts to_output_hash(e).yellow end |
#coastguard_fisma_metrics ⇒ Object
1534 1535 1536 1537 1538 1539 1540 1541 1542 1543 1544 1545 |
# File 'lib/emasser/get.rb', line 1534 def coastguard_fisma_metrics = (@_initializer).keys = to_input_hash(, ) result = EmassClient::CoastGuardSystemFISMAMetricsDashboardApi.new.get_coast_guard_system_fisma_metrics( [:orgId], ) puts to_output_hash(result).green rescue EmassClient::ApiError => e puts 'Exception when calling CoastGuardSystemFISMAMetricsDashboardApi->get_coast_guard_system_fisma_metrics'.red puts to_output_hash(e) end |
#connectivity_ccsd_details ⇒ Object
935 936 937 938 939 940 941 942 943 944 945 946 |
# File 'lib/emasser/get.rb', line 935 def connectivity_ccsd_details = (@_initializer).keys = to_input_hash(, ) result = EmassClient::SystemConnectivityCCSDDashboardsApi.new.get_system_connectivity_ccsd_details( [:orgId], ) puts to_output_hash(result).green rescue EmassClient::ApiError => e puts 'Exception when calling SystemConnectivityCCSDDashboardsApi->get_system_connectivity_ccsd_details'.red puts to_output_hash(e) end |
#connectivity_ccsd_summary ⇒ Object
920 921 922 923 924 925 926 927 928 929 930 931 |
# File 'lib/emasser/get.rb', line 920 def connectivity_ccsd_summary = (@_initializer).keys = to_input_hash(, ) result = EmassClient::SystemConnectivityCCSDDashboardsApi.new.get_system_connectivity_ccsd_summary( [:orgId], ) puts to_output_hash(result).green rescue EmassClient::ApiError => e puts 'Exception when calling SystemConnectivityCCSDDashboardsApi->get_system_connectivity_ccsd_summary'.red puts to_output_hash(e) end |
#control_compliance_summary ⇒ Object
1048 1049 1050 1051 1052 1053 1054 1055 1056 1057 1058 1059 |
# File 'lib/emasser/get.rb', line 1048 def control_compliance_summary = (@_initializer).keys = to_input_hash(, ) result = EmassClient::SystemSecurityControlsDashboardsApi.new.get_system_control_compliance_summary( [:orgId], ) puts to_output_hash(result).green rescue EmassClient::ApiError => e puts 'Exception when calling SystemSecurityControlsDashboardsApi->get_system_control_compliance_summary'.red puts to_output_hash(e) end |
#critical_assets_summary ⇒ Object
1302 1303 1304 1305 1306 1307 1308 1309 1310 1311 1312 1313 |
# File 'lib/emasser/get.rb', line 1302 def critical_assets_summary = (@_initializer).keys = to_input_hash(, ) result = EmassClient::SystemCriticalAssetsDashboardApi.new.get_system_critical_assets_summary( [:orgId], ) puts to_output_hash(result).green rescue EmassClient::ApiError => e puts 'Exception when calling SystemCriticalAssetsDashboardApi->get_system_critical_assets_summary'.red puts to_output_hash(e) end |
#device_findings_details ⇒ Object
1351 1352 1353 1354 1355 1356 1357 1358 1359 1360 1361 1362 |
# File 'lib/emasser/get.rb', line 1351 def device_findings_details = (@_initializer).keys = to_input_hash(, ) result = EmassClient::SystemDeviceFindingsDashboardsApi.new.get_system_device_findings_details( [:orgId], ) puts to_output_hash(result).green rescue EmassClient::ApiError => e puts 'Exception when calling SystemDeviceFindingsDashboardsApi->get_system_device_findings_details'.red puts to_output_hash(e) end |
#device_findings_summary ⇒ Object
1336 1337 1338 1339 1340 1341 1342 1343 1344 1345 1346 1347 |
# File 'lib/emasser/get.rb', line 1336 def device_findings_summary = (@_initializer).keys = to_input_hash(, ) result = EmassClient::SystemDeviceFindingsDashboardsApi.new.get_system_device_findings_summary( [:orgId], ) puts to_output_hash(result).green rescue EmassClient::ApiError => e puts 'Exception when calling SystemDeviceFindingsDashboardsApi->get_system_device_findings_summary'.red puts to_output_hash(e) end |
#fisma_inventory_crypto_summary ⇒ Object
1660 1661 1662 1663 1664 1665 1666 1667 1668 1669 1670 1671 |
# File 'lib/emasser/get.rb', line 1660 def fisma_inventory_crypto_summary = (@_initializer).keys = to_input_hash(, ) result = EmassClient::VASystemDashboardsApi.new.get_va_system_fisma_invetory_crypto_summary( [:orgId], ) puts to_output_hash(result).green rescue EmassClient::ApiError => e puts 'Exception when calling VASystemDashboardsApi->get_va_system_fisma_invetory_crypto_summary'.red puts to_output_hash(e).yellow end |
#fisma_inventory_summary ⇒ Object
1645 1646 1647 1648 1649 1650 1651 1652 1653 1654 1655 1656 |
# File 'lib/emasser/get.rb', line 1645 def fisma_inventory_summary = (@_initializer).keys = to_input_hash(, ) result = EmassClient::VASystemDashboardsApi.new.get_va_system_fisma_invetory_summary( [:orgId], ) puts to_output_hash(result).green rescue EmassClient::ApiError => e puts 'Exception when calling VASystemDashboardsApi->get_va_system_fisma_invetory_summary'.red puts to_output_hash(e).yellow end |
#fisma_metrics ⇒ Object
1517 1518 1519 1520 1521 1522 1523 1524 1525 1526 1527 1528 |
# File 'lib/emasser/get.rb', line 1517 def fisma_metrics = (@_initializer).keys = to_input_hash(, ) result = EmassClient::SystemFISMAMetricsDashboardApi.new.get_system_fisma_metrics( [:orgId], ) puts to_output_hash(result).green rescue EmassClient::ApiError => e puts 'Exception when calling SystemFISMAMetricsDashboardApi->get_system_fisma_metrics'.red puts to_output_hash(e) end |
#fisma_saop_summary ⇒ Object
1568 1569 1570 1571 1572 1573 1574 1575 1576 1577 1578 1579 |
# File 'lib/emasser/get.rb', line 1568 def fisma_saop_summary = (@_initializer).keys = to_input_hash(, ) result = EmassClient::VAOMBFISMADashboardApi.new.get_va_omb_fsma_saop_summary( [:orgId], ) puts to_output_hash(result).green rescue EmassClient::ApiError => e puts 'Exception when calling VAOMBFISMADashboardApi->get_va_omb_fsma_saop_summary'.red puts to_output_hash(e).yellow end |
#hardware_details ⇒ Object
1174 1175 1176 1177 1178 1179 1180 1181 1182 1183 1184 1185 |
# File 'lib/emasser/get.rb', line 1174 def hardware_details = (@_initializer).keys = to_input_hash(, ) result = EmassClient::SystemHardwareDashboardsApi.new.get_system_hardware_details( [:orgId], ) puts to_output_hash(result).green rescue EmassClient::ApiError => e puts 'Exception when calling SystemHardwareDashboardsApi->get_system_hardware_details'.red puts to_output_hash(e) end |
#hardware_summary ⇒ Object
1159 1160 1161 1162 1163 1164 1165 1166 1167 1168 1169 1170 |
# File 'lib/emasser/get.rb', line 1159 def hardware_summary = (@_initializer).keys = to_input_hash(, ) result = EmassClient::SystemHardwareDashboardsApi.new.get_system_hardware_summary( [:orgId], ) puts to_output_hash(result).green rescue EmassClient::ApiError => e puts 'Exception when calling SystemHardwareDashboardsApi->get_system_hardware_summary'.red puts to_output_hash(e) end |
#integration_status_summary ⇒ Object
1432 1433 1434 1435 1436 1437 1438 1439 1440 1441 1442 1443 |
# File 'lib/emasser/get.rb', line 1432 def integration_status_summary = (@_initializer).keys = to_input_hash(, ) result = EmassClient::SystemCONMONIntegrationStatusDashboardApi.new.get_system_common_integration_status_summary( [:orgId], ) puts to_output_hash(result).green rescue EmassClient::ApiError => e puts 'Exception when calling SystemCONMONIntegrationStatusDashboardApi->get_system_common_integration_status_summary'.red puts to_output_hash(e) end |
#organization_migration_status_summary ⇒ Object
1483 1484 1485 1486 1487 1488 1489 1490 1491 1492 1493 1494 |
# File 'lib/emasser/get.rb', line 1483 def organization_migration_status_summary = (@_initializer).keys = to_input_hash(, ) result = EmassClient::OrganizationMigrationStatusDashboardApi.new.get_organization_migration_status_summary( [:orgId], ) puts to_output_hash(result).green rescue EmassClient::ApiError => e puts 'Exception when calling OrganizationMigrationStatusDashboardApi->get_organization_migration_status_summary'.red puts to_output_hash(e) end |
#poam_details ⇒ Object
1110 1111 1112 1113 1114 1115 1116 1117 1118 1119 1120 1121 |
# File 'lib/emasser/get.rb', line 1110 def poam_details = (@_initializer).keys = to_input_hash(, ) result = EmassClient::SystemPOAMDashboardsApi.new.get_system_poam_details( [:orgId], ) puts to_output_hash(result).green rescue EmassClient::ApiError => e puts 'Exception when calling SystemPOAMDashboardsApi->get_system_poam_details'.red puts to_output_hash(e) end |
#poam_summary ⇒ Object
1095 1096 1097 1098 1099 1100 1101 1102 1103 1104 1105 1106 |
# File 'lib/emasser/get.rb', line 1095 def poam_summary = (@_initializer).keys = to_input_hash(, ) result = EmassClient::SystemPOAMDashboardsApi.new.get_system_poam_summary( [:orgId], ) puts to_output_hash(result).green rescue EmassClient::ApiError => e puts 'Exception when calling SystemPOAMDashboardsApi->get_system_poam_summary'.red puts to_output_hash(e) end |
#ports_protocols_details ⇒ Object
1415 1416 1417 1418 1419 1420 1421 1422 1423 1424 1425 1426 |
# File 'lib/emasser/get.rb', line 1415 def ports_protocols_details = (@_initializer).keys = to_input_hash(, ) result = EmassClient::SystemPortsProtocolsDashboardsApi.new.get_system_ports_protocols_details( [:orgId], ) puts to_output_hash(result).green rescue EmassClient::ApiError => e puts 'Exception when calling SystemPortsProtocolsDashboardsApi->get_system_ports_protocols_details'.red puts to_output_hash(e) end |
#ports_protocols_summary ⇒ Object
1400 1401 1402 1403 1404 1405 1406 1407 1408 1409 1410 1411 |
# File 'lib/emasser/get.rb', line 1400 def ports_protocols_summary = (@_initializer).keys = to_input_hash(, ) result = EmassClient::SystemPortsProtocolsDashboardsApi.new.get_system_ports_protocols_summary( [:orgId], ) puts to_output_hash(result).green rescue EmassClient::ApiError => e puts 'Exception when calling SystemPortsProtocolsDashboardsApi->get_system_ports_protocols_summary'.red puts to_output_hash(e) end |
#privacy_summary ⇒ Object
1551 1552 1553 1554 1555 1556 1557 1558 1559 1560 1561 1562 |
# File 'lib/emasser/get.rb', line 1551 def privacy_summary = (@_initializer).keys = to_input_hash(, ) result = EmassClient::SystemPrivacyDashboardApi.new.get_system_privacy_summary( [:orgId], ) puts to_output_hash(result).green rescue EmassClient::ApiError => e puts 'Exception when calling SystemPrivacyDashboardApi->get_system_privacy_summary'.red puts to_output_hash(e) end |
#questionnaire_details ⇒ Object
984 985 986 987 988 989 990 991 992 993 994 995 |
# File 'lib/emasser/get.rb', line 984 def questionnaire_details = (@_initializer).keys = to_input_hash(, ) result = EmassClient::SystemQuestionnaireDashboardsApi.new.get_system_questionnaire_details( [:orgId], ) puts to_output_hash(result).green rescue EmassClient::ApiError => e puts 'Exception when calling SystemQuestionnaireDashboardsApi->get_system_questionnaire_details'.red puts to_output_hash(e) end |
#questionnaire_summary ⇒ Object
969 970 971 972 973 974 975 976 977 978 979 980 |
# File 'lib/emasser/get.rb', line 969 def questionnaire_summary = (@_initializer).keys = to_input_hash(, ) result = EmassClient::SystemQuestionnaireDashboardsApi.new.get_system_questionnaire_summary( [:orgId], ) puts to_output_hash(result).green rescue EmassClient::ApiError => e puts 'Exception when calling SystemQuestionnaireDashboardsApi->get_system_questionnaire_summary'.red puts to_output_hash(e) end |
#security_controls_details ⇒ Object
1063 1064 1065 1066 1067 1068 1069 1070 1071 1072 1073 1074 |
# File 'lib/emasser/get.rb', line 1063 def security_controls_details = (@_initializer).keys = to_input_hash(, ) result = EmassClient::SystemSecurityControlsDashboardsApi.new.get_system_security_control_details( [:orgId], ) puts to_output_hash(result).green rescue EmassClient::ApiError => e puts 'Exception when calling SystemSecurityControlsDashboardsApi->get_system_security_control_details'.red puts to_output_hash(e) end |
#sensor_hardware_details ⇒ Object
1206 1207 1208 1209 1210 1211 1212 1213 1214 1215 1216 1217 |
# File 'lib/emasser/get.rb', line 1206 def sensor_hardware_details = (@_initializer).keys = to_input_hash(, ) result = EmassClient::SystemSensorHardwareDashboardsApi.new.get_system_sensor_hardware_details( [:orgId], ) puts to_output_hash(result).green rescue EmassClient::ApiError => e puts 'Exception when calling SystemSensorHardwareDashboardsApi->get_system_sensor_hardware_details'.red puts to_output_hash(e) end |
#sensor_hardware_summary ⇒ Object
1191 1192 1193 1194 1195 1196 1197 1198 1199 1200 1201 1202 |
# File 'lib/emasser/get.rb', line 1191 def sensor_hardware_summary = (@_initializer).keys = to_input_hash(, ) result = EmassClient::SystemSensorHardwareDashboardsApi.new.get_system_sensor_hardware_summary( [:orgId], ) puts to_output_hash(result).green rescue EmassClient::ApiError => e puts 'Exception when calling SystemSensorHardwareDashboardsApi->get_system_sensor_hardware_summary'.red puts to_output_hash(e) end |
#sensor_software_counts ⇒ Object
1285 1286 1287 1288 1289 1290 1291 1292 1293 1294 1295 1296 |
# File 'lib/emasser/get.rb', line 1285 def sensor_software_counts = (@_initializer).keys = to_input_hash(, ) result = EmassClient::SystemSensorSoftwareDashboardsApi.new.get_system_sensor_software_counts( [:orgId], ) puts to_output_hash(result).green rescue EmassClient::ApiError => e puts 'Exception when calling SystemSensorSoftwareDashboardsApi->get_system_sensor_software_counts'.red puts to_output_hash(e) end |
#sensor_software_details ⇒ Object
1270 1271 1272 1273 1274 1275 1276 1277 1278 1279 1280 1281 |
# File 'lib/emasser/get.rb', line 1270 def sensor_software_details = (@_initializer).keys = to_input_hash(, ) result = EmassClient::SystemSensorSoftwareDashboardsApi.new.get_system_sensor_software_details( [:orgId], ) puts to_output_hash(result).green rescue EmassClient::ApiError => e puts 'Exception when calling SystemSensorSoftwareDashboardsApi->get_system_sensor_software_details'.red puts to_output_hash(e) end |
#sensor_software_summary ⇒ Object
1255 1256 1257 1258 1259 1260 1261 1262 1263 1264 1265 1266 |
# File 'lib/emasser/get.rb', line 1255 def sensor_software_summary = (@_initializer).keys = to_input_hash(, ) result = EmassClient::SystemSensorSoftwareDashboardsApi.new.get_system_sensor_software_summary( [:orgId], ) puts to_output_hash(result).green rescue EmassClient::ApiError => e puts 'Exception when calling SystemSensorSoftwareDashboardsApi->get_system_sensor_software_summary'.red puts to_output_hash(e) end |
#software_details ⇒ Object
1238 1239 1240 1241 1242 1243 1244 1245 1246 1247 1248 1249 |
# File 'lib/emasser/get.rb', line 1238 def software_details = (@_initializer).keys = to_input_hash(, ) result = EmassClient::SystemSoftwareDashboardsApi.new.get_system_software_details( [:orgId], ) puts to_output_hash(result).green rescue EmassClient::ApiError => e puts 'Exception when calling SystemSoftwareDashboardsApi->get_system_software_details'.red puts to_output_hash(e) end |
#software_summary ⇒ Object
1223 1224 1225 1226 1227 1228 1229 1230 1231 1232 1233 1234 |
# File 'lib/emasser/get.rb', line 1223 def software_summary = (@_initializer).keys = to_input_hash(, ) result = EmassClient::SystemSoftwareDashboardsApi.new.get_system_software_summary( [:orgId], ) puts to_output_hash(result).green rescue EmassClient::ApiError => e puts 'Exception when calling SystemSoftwareDashboardsApi->get_system_software_summary'.red puts to_output_hash(e) end |
#status_details ⇒ Object
871 872 873 874 875 876 877 878 879 880 881 882 |
# File 'lib/emasser/get.rb', line 871 def status_details = (@_initializer).keys = to_input_hash(, ) result = EmassClient::SystemStatusDashboardApi.new.get_system_status_details( [:orgId], ) puts to_output_hash(result).green rescue EmassClient::ApiError => e puts 'Exception when calling SystemStatusDashboardApi->get_system_status_details'.red puts to_output_hash(e) end |
#system_migration_status_summary ⇒ Object
1500 1501 1502 1503 1504 1505 1506 1507 1508 1509 1510 1511 |
# File 'lib/emasser/get.rb', line 1500 def system_migration_status_summary = (@_initializer).keys = to_input_hash(, ) result = EmassClient::SystemMigrationStatusDashboardApi.new.get_system_migration_status_summary( [:orgId], ) puts to_output_hash(result).green rescue EmassClient::ApiError => e puts 'Exception when calling SystemMigrationStatusDashboardApi->get_system_migration_status_summary'.red puts to_output_hash(e) end |
#terms_conditions_details ⇒ Object
903 904 905 906 907 908 909 910 911 912 913 914 |
# File 'lib/emasser/get.rb', line 903 def terms_conditions_details = (@_initializer).keys = to_input_hash(, ) result = EmassClient::SystemTermsConditionsDashboardsApi.new.get_system_terms_conditions_details( [:orgId], ) puts to_output_hash(result).green rescue EmassClient::ApiError => e puts 'Exception when calling SystemTermsConditionsDashboardsApi->get_system_terms_conditions_details'.red puts to_output_hash(e) end |
#terms_conditions_summary ⇒ Object
888 889 890 891 892 893 894 895 896 897 898 899 |
# File 'lib/emasser/get.rb', line 888 def terms_conditions_summary = (@_initializer).keys = to_input_hash(, ) result = EmassClient::SystemTermsConditionsDashboardsApi.new.get_system_terms_conditions_summary( [:orgId], ) puts to_output_hash(result).green rescue EmassClient::ApiError => e puts 'Exception when calling SystemTermsConditionsDashboardsApi->get_system_terms_conditions_summary'.red puts to_output_hash(e) end |
#threat_architecture_details ⇒ Object
1705 1706 1707 1708 1709 1710 1711 1712 1713 1714 1715 1716 |
# File 'lib/emasser/get.rb', line 1705 def threat_architecture_details = (@_initializer).keys = to_input_hash(, ) result = EmassClient::VASystemDashboardsApi.new.get_va_system_threat_architecture_details( [:orgId], ) puts to_output_hash(result).green rescue EmassClient::ApiError => e puts 'Exception when calling VASystemDashboardsApi->get_va_system_threat_architecture_details'.red puts to_output_hash(e).yellow end |
#threat_risk_details ⇒ Object
1690 1691 1692 1693 1694 1695 1696 1697 1698 1699 1700 1701 |
# File 'lib/emasser/get.rb', line 1690 def threat_risk_details = (@_initializer).keys = to_input_hash(, ) result = EmassClient::VASystemDashboardsApi.new.get_va_system_threat_source_details( [:orgId], ) puts to_output_hash(result).green rescue EmassClient::ApiError => e puts 'Exception when calling VASystemDashboardsApi->get_va_system_threat_source_details'.red puts to_output_hash(e).yellow end |
#threat_risk_summary ⇒ Object
1675 1676 1677 1678 1679 1680 1681 1682 1683 1684 1685 1686 |
# File 'lib/emasser/get.rb', line 1675 def threat_risk_summary = (@_initializer).keys = to_input_hash(, ) result = EmassClient::VASystemDashboardsApi.new.get_va_system_threat_risk_summary( [:orgId], ) puts to_output_hash(result).green rescue EmassClient::ApiError => e puts 'Exception when calling VASystemDashboardsApi->get_va_system_threat_risk_summary'.red puts to_output_hash(e).yellow end |
#va_a2_summary ⇒ Object
1615 1616 1617 1618 1619 1620 1621 1622 1623 1624 1625 1626 |
# File 'lib/emasser/get.rb', line 1615 def va_a2_summary = (@_initializer).keys = to_input_hash(, ) result = EmassClient::VASystemDashboardsApi.new.get_va_system_a2_summary( [:orgId], ) puts to_output_hash(result).green rescue EmassClient::ApiError => e puts 'Exception when calling VASystemDashboardsApi->get_va_system_a2_summary'.red puts to_output_hash(e).yellow end |
#va_aa_summary ⇒ Object
1600 1601 1602 1603 1604 1605 1606 1607 1608 1609 1610 1611 |
# File 'lib/emasser/get.rb', line 1600 def va_aa_summary = (@_initializer).keys = to_input_hash(, ) result = EmassClient::VASystemDashboardsApi.new.get_va_system_aa_summary( [:orgId], ) puts to_output_hash(result).green rescue EmassClient::ApiError => e puts 'Exception when calling VASystemDashboardsApi->get_va_system_aa_summary'.red puts to_output_hash(e).yellow end |
#va_icamp_tableau_poam_details ⇒ Object
1585 1586 1587 1588 1589 1590 1591 1592 1593 1594 1595 1596 |
# File 'lib/emasser/get.rb', line 1585 def va_icamp_tableau_poam_details = (@_initializer).keys = to_input_hash(, ) result = EmassClient::VASystemDashboardsApi.new.get_va_system_icamp_tableau_poam_details( [:orgId], ) puts to_output_hash(result).green rescue EmassClient::ApiError => e puts 'Exception when calling VASystemDashboardsApi->get_va_system_icamp_tableau_poam_details'.red puts to_output_hash(e).yellow end |
#va_pl_109_summary ⇒ Object
1630 1631 1632 1633 1634 1635 1636 1637 1638 1639 1640 1641 |
# File 'lib/emasser/get.rb', line 1630 def va_pl_109_summary = (@_initializer).keys = to_input_hash(, ) result = EmassClient::VASystemDashboardsApi.new.get_va_system_pl109_reporting_summary( [:orgId], ) puts to_output_hash(result).green rescue EmassClient::ApiError => e puts 'Exception when calling VASystemDashboardsApi->get_va_system_pl109_reporting_summary'.red puts to_output_hash(e).yellow end |
#vulnerability_summary ⇒ Object
1319 1320 1321 1322 1323 1324 1325 1326 1327 1328 1329 1330 |
# File 'lib/emasser/get.rb', line 1319 def vulnerability_summary = (@_initializer).keys = to_input_hash(, ) result = EmassClient::SystemVulnerabilityDashboardApi.new.get_system_vulnerability_summary( [:orgId], ) puts to_output_hash(result).green rescue EmassClient::ApiError => e puts 'Exception when calling SystemVulnerabilityDashboardApi->get_system_vulnerability_summary'.red puts to_output_hash(e) end |
#workflows_history_details ⇒ Object
1016 1017 1018 1019 1020 1021 1022 1023 1024 1025 1026 1027 |
# File 'lib/emasser/get.rb', line 1016 def workflows_history_details = (@_initializer).keys = to_input_hash(, ) result = EmassClient::SystemWorkflowsDashboardsApi.new.get_system_workflows_history_details( [:orgId], ) puts to_output_hash(result).green rescue EmassClient::ApiError => e puts 'Exception when calling SystemWorkflowsDashboardsApi->get_system_workflows_history_details'.red puts to_output_hash(e) end |
#workflows_history_stage_details ⇒ Object
1031 1032 1033 1034 1035 1036 1037 1038 1039 1040 1041 1042 |
# File 'lib/emasser/get.rb', line 1031 def workflows_history_stage_details = (@_initializer).keys = to_input_hash(, ) result = EmassClient::SystemWorkflowsDashboardsApi.new.get_system_workflows_history_stage_details( [:orgId], ) puts to_output_hash(result).green rescue EmassClient::ApiError => e puts 'Exception when calling SystemWorkflowsDashboardsApi->get_system_workflows_history_stage_details'.red puts to_output_hash(e) end |
#workflows_history_summary ⇒ Object
1001 1002 1003 1004 1005 1006 1007 1008 1009 1010 1011 1012 |
# File 'lib/emasser/get.rb', line 1001 def workflows_history_summary = (@_initializer).keys = to_input_hash(, ) result = EmassClient::SystemWorkflowsDashboardsApi.new.get_system_workflows_history_summary( [:orgId], ) puts to_output_hash(result).green rescue EmassClient::ApiError => e puts 'Exception when calling SystemWorkflowsDashboardsApi->get_system_workflows_history_summary'.red puts to_output_hash(e) end |